@@ -62,8 +62,8 @@ def run_wizard(func, exp_list=None, exp_groups=None, job_config=None, results_fn
                     job_config=job_config,
                     )
 
-        command = ('python trainval.py -ei <exp_id> -sb %s' %  
-                  (args.savedir_base))
+        command = ('python trainval.py -ei <exp_id> -sb %s -d %s' %  
+                  (args.savedir_base, args.datadir))
 
         print(command)
         jm.launch_menu(command=command)
